==> django-data-models-0.0.32.tar.gz: django-data-models-0.0.32/datamodels/management/commands/datamodels_loaddata.py <==
import os
import warnings

import django.apps
from django.conf import settings
from django.core import serializers
from django.core.management import call_command, CommandError
from django.core.management.base import BaseCommand
from django.core.management.commands.loaddata import humanize
from django.db import router, DatabaseError, IntegrityError
from django.utils.encoding import force_text
from django.utils.module_loading import import_string

from ...models import DataModel

DJANGO_LOADDATA_COMMAND = 'django.core.management.commands.loaddata.Command'
LOADDATA_COMMAND_CLASS = getattr(settings, 'DATAMODELS_LOADDATA_COMMAND_CLASS', DJANGO_LOADDATA_COMMAND)
LoaddataCommand = import_string(LOADDATA_COMMAND_CLASS)


class Command(BaseCommand):
    help = 'Loads data for all DataModels'
    verbosity = 1

    def add_arguments(self, parser):
        parser.add_argument(
            'args', metavar='labels', nargs='*',
            help='Module paths to datamodel; can be appname or appname.ModelName'
        )

    def handle(self, *args, **options):
        self.verbosity = options['verbosity']

        data_models = self.get_data_models()
        data_models = self.filter_data_models(data_models, args)

        loaded_models = []
        for model in data_models:
            self.load_model_fixtures(model, loaded_models=loaded_models)

    def get_data_models(self):
        return [model for model in django.apps.apps.get_models() if issubclass(model, DataModel)]

    @staticmethod
    def filter_data_models(data_models, filter_labels):
        if not filter_labels:
            return data_models
        filtered_data_models = []
        for filter in filter_labels:
            for model in data_models:
                if model._meta.label.lower() == filter.lower():  # Assume label
                    filtered_data_models.append(model)
                elif model._meta.app_label.lower() == filter.lower():  # Assume app label
                    filtered_data_models.append(model)
        return filtered_data_models

    def load_model_fixtures(self, model, loaded_models):
        if model in loaded_models:
            return

        self.load_dependencies(model, loaded_models)

        fixtures = getattr(model.DataModelMeta, 'fixtures', None) or []
        for fixture in fixtures:
            if self.verbosity >= 1:
                print("Loading %s..." % fixture)
            call_command(LoaddataCommand(), fixture, verbosity=self.verbosity, skip_checks=True)
            if self.verbosity >= 1:
                print('')

        default_fixtures = getattr(model.DataModelMeta, 'default_fixtures', None) or []
        for fixture in default_fixtures:
            if self.verbosity >= 1:
                print("Loading default %s..." % fixture)
            call_command(DefaultOnlyLoaddataComand(), fixture, verbosity=self.verbosity, skip_checks=True)
            if self.verbosity >= 1:
                print('')

        loaded_models.append(model)

    def load_dependencies(self, model, loaded_models):
        if not issubclass(model, DataModel):
            raise Exception('%s was set as datamodel dependency, but it\'s not a DataModel' % (unicode(model)))

        dependencies = getattr(model.DataModelMeta, 'dependencies', None) or []
        for dep_model_str in dependencies:
            app_label, model_name = dep_model_str.split('.')
            dep_model = django.apps.apps.get_model(model_name=model_name, app_label=app_label)
            self.load_model_fixtures(dep_model, loaded_models=loaded_models)


class DefaultOnlyLoaddataComand(LoaddataCommand):
    def load_label(self, fixture_label):
        """
        Loads fixtures files for a given label.
        """
        show_progress = self.verbosity >= 3
        for fixture_file, fixture_dir, fixture_name in self.find_fixtures(fixture_label):
            _, ser_fmt, cmp_fmt = self.parse_name(os.path.basename(fixture_file))
            open_method, mode = self.compression_formats[cmp_fmt]
            fixture = open_method(fixture_file, mode)
            try:
                self.fixture_count += 1
                objects_in_fixture = 0
                loaded_objects_in_fixture = 0
                if self.verbosity >= 2:
                    self.stdout.write(
                        "Installing %s fixture '%s' from %s."
                        % (ser_fmt, fixture_name, humanize(fixture_dir))
                    )
                objects = serializers.deserialize(
                    ser_fmt, fixture, using=self.using, ignorenonexistent=self.ignore,
                )

                for obj in objects:
                    objects_in_fixture += 1
                    if router.allow_migrate_model(self.using, obj.object.__class__):
                        self.models.add(obj.object.__class__)
                        try:
                            if obj.object.__class__.objects.filter(id=obj.object.id).exists():
                                continue
                            loaded_objects_in_fixture += 1
                            obj.save(using=self.using)
                            if show_progress:
                                self.stdout.write(
                                    '\rProcessed %i object(s).' % loaded_objects_in_fixture,
                                    ending=''
                                )
                        except (DatabaseError, IntegrityError) as e:
                            e.args = ("Could not load %(app_label)s.%(object_name)s(pk=%(pk)s): %(error_msg)s" % {
                                'app_label': obj.object._meta.app_label,
                                'object_name': obj.object._meta.object_name,
                                'pk': obj.object.pk,
                                'error_msg': force_text(e)
                            },)
                            raise
                if objects and show_progress:
                    self.stdout.write('')  # add a newline after progress indicator
                self.loaded_object_count += loaded_objects_in_fixture
                self.fixture_object_count += objects_in_fixture
            except Exception as e:
                if not isinstance(e, CommandError):
                    e.args = ("Problem installing fixture '%s': %s" % (fixture_file, e),)
                raise
            finally:
                fixture.close()

            # Warn if the fixture we loaded contains 0 objects.
            if objects_in_fixture == 0:
                warnings.warn(
                    "No fixture data found for '%s'. (File format may be "
                    "invalid.)" % fixture_name,
                    RuntimeWarning
                )

==> django-data-models-0.0.38.tar.gz: django-data-models-0.0.38/datamodels/management/commands/datamodels_loaddata.py <==
import django
import django.apps
from django.conf import settings
from django.core.management import call_command
from django.core.management.base import BaseCommand
from django.utils.module_loading import import_string

from ...models import DataModel

DJANGO_LOADDATA_COMMAND = 'django.core.management.commands.loaddata.Command'
LOADDATA_COMMAND_CLASS = getattr(settings, 'DATAMODELS_LOADDATA_COMMAND_CLASS', DJANGO_LOADDATA_COMMAND)
LoaddataCommand = import_string(LOADDATA_COMMAND_CLASS)


class Command(BaseCommand):
    help = 'Loads data for all DataModels'
    verbosity = 1

    def add_arguments(self, parser):
        parser.add_argument(
            'args', metavar='labels', nargs='*',
            help='Module paths to datamodel; can be appname or appname.ModelName'
        )

    def handle(self, *args, **options):
        self.verbosity = options['verbosity']

        data_models = self.get_data_models()
        data_models = self.filter_data_models(data_models, args)

        loaded_models = []
        for model in data_models:
            self.load_model_fixtures(model, loaded_models=loaded_models)

    def get_data_models(self):
        return [model for model in django.apps.apps.get_models() if issubclass(model, DataModel)]

    @staticmethod
    def filter_data_models(data_models, filter_labels):
        if not filter_labels:
            return data_models
        filtered_data_models = []
        for filter in filter_labels:
            for model in data_models:
                if model._meta.label.lower() == filter.lower():  # Assume label
                    filtered_data_models.append(model)
                elif model._meta.app_label.lower() == filter.lower():  # Assume app label
                    filtered_data_models.append(model)
        return filtered_data_models

    def load_model_fixtures(self, model, loaded_models):
        if model in loaded_models:
            return

        self.load_dependencies(model, loaded_models)

        fixtures = getattr(model.DataModelMeta, 'fixtures', None) or []
        for fixture in fixtures:
            if self.verbosity >= 1:
                print("Loading %s..." % fixture)
            if django.VERSION < (1, 10):
                # Django 1.8 and 1.9 doesn't support command class as call_command's first argument
                # So we need to extract command name from path
                # 1. django.core.management.commands.loaddata.Command => loaddata.Command
                # 2. loaddata.Command => ['loaddata', 'Command'][0]
                command_name = DJANGO_LOADDATA_COMMAND.split('commands.')[-1].split('.')[0]
                call_command(command_name, fixture, verbosity=self.verbosity, skip_checks=True)
            else:
                call_command(LoaddataCommand(), fixture, verbosity=self.verbosity, skip_checks=True)

            if self.verbosity >= 1:
                print('')

        default_fixtures = getattr(model.DataModelMeta, 'default_fixtures', None) or []
        for fixture in default_fixtures:
            if self.verbosity >= 1:
                print("Loading default %s..." % fixture)
            call_command('datamodels_loaddata_default', fixture, verbosity=self.verbosity, skip_checks=True)
            if self.verbosity >= 1:
                print('')

        loaded_models.append(model)

    def load_dependencies(self, model, loaded_models):
        if not issubclass(model, DataModel):
            raise Exception('%s was set as datamodel dependency, but it\'s not a DataModel' % (unicode(model)))

        dependencies = getattr(model.DataModelMeta, 'dependencies', None) or []
        for dep_model_str in dependencies:
            app_label, model_name = dep_model_str.split('.')
            dep_model = django.apps.apps.get_model(model_name=model_name, app_label=app_label)
            self.load_model_fixtures(dep_model, loaded_models=loaded_models)
